"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PdfMerge = void 0;
const n8n_workflow_1 = require("n8n-workflow");
const n8n_workflow_2 = require("n8n-workflow");
const PdfMergeUtils_1 = require("./PdfMergeUtils");
const nodeOperationOptions = [
    {
        displayName: 'Property Name 1',
        name: 'dataPropertyName1',
        type: 'string',
        default: 'data',
        description: 'Name of the binary property for the first input which holds the document to be used',
    },
    {
        displayName: 'Property Name 2',
        name: 'dataPropertyName2',
        type: 'string',
        default: 'data',
        description: 'Name of the binary property for the second input which holds the document to be used',
    },
    {
        displayName: 'Property Name Out',
        name: 'dataPropertyNameOut',
        type: 'string',
        default: 'data',
        description: 'Name of the binary property where the combined document will be output',
    },
];
class PdfMerge {
    constructor() {
        this.description = {
            displayName: 'Merge PDF',
            name: 'pdfMerge',
            icon: 'file:merge.svg',
            group: ['transform'],
            version: 1,
            description: 'Merges two PDF documents',
            defaults: {
                name: 'Merge PDF',
            },
            inputs: ['main', 'main'],
            inputNames: ['Document 1', 'Document 2'],
            outputs: ['main'],
            properties: [...nodeOperationOptions],
        };
    }
    async execute() {
        const items1 = this.getInputData(0);
        const items2 = this.getInputData(1);
        if (items1.length !== items2.length) {
            throw new n8n_workflow_1.NodeOperationError(this.getNode(), `Invalid inut lengths! Both inputs should have the same number of items, but had ${items1.length} and ${items2.length} items, respectively.`);
        }
        const returnData = [];
        for (let itemIndex = 0; itemIndex < items1.length; itemIndex++) {
            const dataPropertyName1 = this.getNodeParameter('dataPropertyName1', itemIndex);
            const dataPropertyName2 = this.getNodeParameter('dataPropertyName2', itemIndex);
            const dataPropertyNameOut = this.getNodeParameter('dataPropertyNameOut', itemIndex);
            const item1 = items1[itemIndex];
            const item2 = items2[itemIndex];
            try {
                const binaryData1 = this.helpers.assertBinaryData(itemIndex, dataPropertyName1);
                const binaryData2 = this.helpers.assertBinaryData(itemIndex, dataPropertyName2);
                if (!(0, PdfMergeUtils_1.isPDFDocument)(binaryData1)) {
                    throw new n8n_workflow_1.NodeOperationError(this.getNode(), `Input 1 (on binary property "${dataPropertyName2}") should be a PDF file, was ${binaryData2.mimeType} instead`, { itemIndex });
                }
                if (!(0, PdfMergeUtils_1.isPDFDocument)(binaryData2)) {
                    throw new n8n_workflow_1.NodeOperationError(this.getNode(), `Input 2 (on binary property "${dataPropertyName2}") should be a PDF file, was ${binaryData2.mimeType} instead`, { itemIndex });
                }
                let fileContent1;
                if (binaryData1.id) {
                    fileContent1 = await this.helpers.binaryToBuffer(this.helpers.getBinaryStream(binaryData1.id));
                }
                else {
                    fileContent1 = Buffer.from(binaryData1.data, n8n_workflow_2.BINARY_ENCODING);
                }
                let fileContent2;
                if (binaryData2.id) {
                    fileContent2 = await this.helpers.binaryToBuffer(this.helpers.getBinaryStream(binaryData2.id));
                }
                else {
                    fileContent2 = Buffer.from(binaryData2.data, n8n_workflow_2.BINARY_ENCODING);
                }
                const merged = await (0, PdfMergeUtils_1.mergePdfs)(fileContent1, fileContent2);
                returnData.push({
                    json: {
                        ...item1.json,
                        ...item2.json,
                    },
                    binary: {
                        ...item1.binary,
                        ...item2.binary,
                        [dataPropertyNameOut]: await this.helpers.prepareBinaryData(merged, dataPropertyNameOut + '.pdf', 'application/pdf'),
                    },
                    pairedItem: [item1.pairedItem, item2.pairedItem],
                });
            }
            catch (error) {
                if (this.continueOnFail()) {
                    returnData.push({
                        json: {
                            ...item1.json,
                            ...item2.json,
                        },
                        binary: {
                            ...item1.binary,
                            ...item2.binary,
                        },
                        pairedItem: [item1.pairedItem, item2.pairedItem],
                    });
                }
                else {
                    if (error.context) {
                        error.context.itemIndex = itemIndex;
                        throw error;
                    }
                    throw new n8n_workflow_1.NodeOperationError(this.getNode(), error, {
                        itemIndex,
                    });
                }
            }
        }
        return [returnData];
    }
}
exports.PdfMerge = PdfMerge;
//# sourceMappingURL=PdfMerge.node.js.map